==> igniteui-react-charts-18.1.0.tgz: package/esm2015/lib/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AbsoluteVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class AbsoluteVolumeOscillatorIndicator extends StrategyBasedIndicator {
        get_ul() {
            return new AbsoluteVolumeOscillatorIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return AbsoluteVolumeOscillatorIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get shortPeriod() {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.u7));
        }
        set shortPeriod(a) {
            this.h(AbsoluteVolumeOscillatorIndicator.u7, a);
        }
        ut() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.u6));
        }
        set longPeriod(a) {
            this.h(AbsoluteVolumeOscillatorIndicator.u6, a);
        }
        uq() {
            return this.longPeriod;
        }
    }
    AbsoluteVolumeOscillatorIndicator.$t = /*@__PURE__*/ markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    AbsoluteVolumeOscillatorIndicator.u7 = /*@__PURE__*/ StrategyBasedIndicator.u5(10, AbsoluteVolumeOscillatorIndicator.$);
    AbsoluteVolumeOscillatorIndicator.u6 = /*@__PURE__*/ StrategyBasedIndicator.u1(30, AbsoluteVolumeOscillatorIndicator.$);
    return AbsoluteVolumeOscillatorIndicator;
})();

==> igniteui-react-charts-18.5.1.tgz: package/esm2015/lib/AbsoluteVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { AbsoluteVolumeOscillatorIndicatorStrategy } from "./AbsoluteVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let AbsoluteVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class AbsoluteVolumeOscillatorIndicator extends StrategyBasedIndicator {
        bg() {
            return new AbsoluteVolumeOscillatorIndicator();
        }
        get_yz() {
            return new AbsoluteVolumeOscillatorIndicatorStrategy();
        }
        get yz() {
            return this.get_yz();
        }
        get_zc() {
            return AbsoluteVolumeOscillatorIndicator.$;
        }
        get zc() {
            return this.get_zc();
        }
        get shortPeriod() {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.zl));
        }
        set shortPeriod(a) {
            this.h(AbsoluteVolumeOscillatorIndicator.zl, a);
        }
        y7() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(AbsoluteVolumeOscillatorIndicator.zk));
        }
        set longPeriod(a) {
            this.h(AbsoluteVolumeOscillatorIndicator.zk, a);
        }
        y4() {
            return this.longPeriod;
        }
    }
    AbsoluteVolumeOscillatorIndicator.$t = /*@__PURE__*/ markType(AbsoluteVolumeOscillatorIndicator, 'AbsoluteVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    AbsoluteVolumeOscillatorIndicator.zl = /*@__PURE__*/ StrategyBasedIndicator.zj(10, AbsoluteVolumeOscillatorIndicator.$);
    AbsoluteVolumeOscillatorIndicator.zk = /*@__PURE__*/ StrategyBasedIndicator.zf(30, AbsoluteVolumeOscillatorIndicator.$);
    return AbsoluteVolumeOscillatorIndicator;
})();
